@@ -1,5 +1,6 @@
 package Text::Format;
-require 5.003;
+
+require 5.006;
 
 =head1 NAME
 
@@ -56,7 +57,7 @@ is set to a small number and words are longer than that and the leading
 let you make a simple word list which could be indented or right
 aligned.  There is a chance for croaking if you try to subvert the
 module.  If you don't pass in text then the internal text is worked on,
-though not modfied.
+though not modified.
 
 I<Text::Format> is meant for more powerful text formatting than what
 I<Text::Wrap> allows.  I also have a module called I<Text::NWrap> that
@@ -289,6 +290,13 @@ if columns is set to a small number and long words plus leading whitespace
 exceed the specified column length.  Actually I see this as a feature since it
 can be used to make up a nice word list.
 
+=head1 LICENSE
+
+Copyright (c) 1998 Gabor Egressy.  All rights reserved.
+
+This program is free software; you can redistribute and/or
+modify it under the same terms as Perl itself.
+
 =head1 AUTHOR
 
 Gabor Egressy B<gabor@vmunix.com>
@@ -334,11 +342,14 @@ B<noBreakRegex> , thanks to a report with a problem.
 
 =cut
 
-use Carp;
 use strict;
+use warnings;
+
+use Carp;
+
 use vars qw($VERSION);
 
-$VERSION = '0.58';
+$VERSION = '0.60';
 
 # local abbreviations, you can add your own with abbrevs()
 my %abbrev = (
